@@ -15,12 +15,6 @@ class CookieRedirectingFormPlugin(object):
     :param logout_handler_path: relative URL to logout process
     :param rememberer_name: identifier plugin that handles remember/forget headers
     :param default_redirect_path: relative URL that user is redirected to if all methods fail
-    :param error_field: name of the cookie that error messages are stored
-
-    The following error is stored in a cookie:
-
-    `MISSING_PARAM` -- ``login`` and ``password`` input fields must be present
-
     """
 
     implements(IChallenger, IIdentifier)
@@ -30,14 +24,12 @@ class CookieRedirectingFormPlugin(object):
             login_handler_path,
             logout_handler_path,
             rememberer_name,
-            default_redirect_path='/',
-            error_field='repoze.who.error'):
+            default_redirect_path='/'):
         self.login_form_path = login_form_path
         self.login_handler_path = login_handler_path
         self.logout_handler_path = logout_handler_path
         self.rememberer_name = rememberer_name
         self.default_redirect_path = default_redirect_path
-        self.error_field = error_field
 
     def _extract_came_from(self, environ, use_current=False):
         """
@@ -107,10 +99,8 @@ class CookieRedirectingFormPlugin(object):
                 if log:
                     log.debug('login failed: both login '
                         'and password form inputs must be given')
-                headers = SET_COOKIE.tuples('%s=%s; Path=/;' % (
-                    self.error_field, 'MISSING_PARAM'))
                 environ['repoze.who.application'] = \
-                    HTTPFound(self.login_form_path, headers=headers)
+                    HTTPFound(self.login_form_path)
                 return None
 
             # get cookies and search for 'came_from'
@@ -151,8 +141,7 @@ class CookieRedirectingFormPlugin(object):
         cookie = SET_COOKIE.tuples('%s=""; Path=/; Expires=Sun, 10-May-1971 '
             '11:59:00 GMT;' % ('came_from'))
         headers = rememberer.remember(environ, identity)
-        if headers:
-            cookie.append(headers)
+        cookie += headers
         return cookie
 
     def forget(self, environ, identity):
@@ -176,7 +165,6 @@ def make_redirecting_plugin(login_form_path=None,
         logout_handle_path = /logout
         rememberer_name = cookie
         default_redirect_path = /home
-        error_field = repoze.who.failure
 
         [plugin:cookie]
         use = repoze.who.plugins.auth_tkt:make_plugin
